@@ -1,3 +1,5 @@
+from enum import Enum
+
 import os
 import sys
 
@@ -75,9 +77,18 @@ class TEST_RECOMMENDATION(object):
     timeout_sec = 60
     interval_sec = 5
     RSS = 'recommendationSetStatus'
-    RSS_NOT_READY = 'notready'
+    RSS_NOT_READY = 'notReady'
     RSS_NO_HISTORY = 'noHistory'
     RSS_READY = 'ready'
     RSS_ERROR = 'error'
+    RSS_WONT_BE_READY = 'wontBeReady'
     TEST_SELECTION_ENABLED = "testSelectionEnabled"
 
+
+class TestSelectionStatus(str, Enum):
+    RECOMMENDED_TESTS = "recommendedTests"
+    DISABLED = "disabled"
+    DISABLED_BY_CONFIGURATION = "disabledByConfiguration"
+    RECOMMENDATIONS_TIMEOUT = "recommendationsTimeout"
+    RECOMMENDATIONS_TIMEOUT_SERVER = "recommendationsTimeoutOnServer"
+    ERROR = "error"
